package com.perforce.hwsclient.models;

import java.util.Objects;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.util.*;
import java.util.Date;

import com.google.gson.annotations.SerializedName;




/**
 * Models the output of a `p4 branch` command.\n\nFor more information see the [command reference](https://www.perforce.com/perforce/doc.current/manuals/cmdref/p4_branch.html).
 **/
@ApiModel(description = "Models the output of a `p4 branch` command.\n\nFor more information see the [command reference](https://www.perforce.com/perforce/doc.current/manuals/cmdref/p4_branch.html).")
public class BranchCommand   {
  
  @SerializedName("branch")
  private String branch = null;
  
  @SerializedName("owner")
  private String owner = null;
  
  @SerializedName("access")
  private Date access = null;
  
  @SerializedName("update")
  private Date update = null;
  
  @SerializedName("options")
  private String options = null;
  
  @SerializedName("description")
  private String description = null;
  
  @SerializedName("view")
  private List<String> view = new ArrayList<String>();
  

  
  /**
   * The branch name, as provided on the command line.
   **/
  @ApiModelProperty(value = "The branch name, as provided on the command line.")
  public String getBranch() {
    return branch;
  }
  public void setBranch(String branch) {
    this.branch = branch;
  }

  
  /**
   * The owner of the branch mapping.\nBy default, this will be set to the user who created the branch.\nThis field is unimportant unless the Option: field value is locked.
   **/
  @ApiModelProperty(value = "The owner of the branch mapping.\nBy default, this will be set to the user who created the branch.\nThis field is unimportant unless the Option: field value is locked.")
  public String getOwner() {
    return owner;
  }
  public void setOwner(String owner) {
    this.owner = owner;
  }

  
  /**
   * The date the branch mapping was last accessed.
   **/
  @ApiModelProperty(value = "The date the branch mapping was last accessed.")
  public Date getAccess() {
    return access;
  }
  public void setAccess(Date access) {
    this.access = access;
  }

  
  /**
   * The date the branch mapping was last changed.
   **/
  @ApiModelProperty(value = "The date the branch mapping was last changed.")
  public Date getUpdate() {
    return update;
  }
  public void setUpdate(Date update) {
    this.update = update;
  }

  
  /**
   * Either `unlocked` (the default) or `locked`.\n\nIf `locked`, only the `Owner:` can modify the branch mapping, and the mapping can't be deleted until it is `unlocked`.
   **/
  @ApiModelProperty(value = "Either `unlocked` (the default) or `locked`.\n\nIf `locked`, only the `Owner:` can modify the branch mapping, and the mapping can't be deleted until it is `unlocked`.")
  public String getOptions() {
    return options;
  }
  public void setOptions(String options) {
    this.options = options;
  }

  
  /**
   * A short description of the branch's purpose.
   **/
  @ApiModelProperty(value = "A short description of the branch's purpose.")
  public String getDescription() {
    return description;
  }
  public void setDescription(String description) {
    this.description = description;
  }

  
  /**
   * A set of mappings from one set of files in the depot (the source files) to another set of files in the depot (the target files).\n	The view maps from one location in the depot to another; it can't refer to a client workspace.\n\n  For example, the branch view `//depot/main/... //depot/r2.1/...` maps all the files under `//depot/main` to `//depot/r2.1`.
   **/
  @ApiModelProperty(value = "A set of mappings from one set of files in the depot (the source files) to another set of files in the depot (the target files).\n	The view maps from one location in the depot to another; it can't refer to a client workspace.\n\n  For example, the branch view `//depot/main/... //depot/r2.1/...` maps all the files under `//depot/main` to `//depot/r2.1`.")
  public List<String> getView() {
    return view;
  }
  public void setView(List<String> view) {
    this.view = view;
  }

  

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    BranchCommand branchCommand = (BranchCommand) o;
    return Objects.equals(this.branch, branchCommand.branch) &&
        Objects.equals(this.owner, branchCommand.owner) &&
        Objects.equals(this.access, branchCommand.access) &&
        Objects.equals(this.update, branchCommand.update) &&
        Objects.equals(this.options, branchCommand.options) &&
        Objects.equals(this.description, branchCommand.description) &&
        Objects.equals(this.view, branchCommand.view);
  }

  @Override
  public int hashCode() {
    return Objects.hash(branch, owner, access, update, options, description, view);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class BranchCommand {\n");
    
    sb.append("    branch: ").append(toIndentedString(branch)).append("\n");
    sb.append("    owner: ").append(toIndentedString(owner)).append("\n");
    sb.append("    access: ").append(toIndentedString(access)).append("\n");
    sb.append("    update: ").append(toIndentedString(update)).append("\n");
    sb.append("    options: ").append(toIndentedString(options)).append("\n");
    sb.append("    description: ").append(toIndentedString(description)).append("\n");
    sb.append("    view: ").append(toIndentedString(view)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
