package com.perforce.hwsclient.models;

import java.util.Objects;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.util.*;
import java.util.Date;

import com.google.gson.annotations.SerializedName;




/**
 * A changelist specification.\n\nFor more information see the [command reference](https://www.perforce.com/perforce/doc.current/manuals/cmdref/p4_change.html).
 **/
@ApiModel(description = "A changelist specification.\n\nFor more information see the [command reference](https://www.perforce.com/perforce/doc.current/manuals/cmdref/p4_change.html).")
public class ChangeCommand   {
  
  @SerializedName("change")
  private String change = null;
  
  @SerializedName("client")
  private String client = null;
  
  @SerializedName("date")
  private Date date = null;
  
  @SerializedName("user")
  private String user = null;
  
  @SerializedName("status")
  private String status = null;
  
  @SerializedName("description")
  private String description = null;
  
  @SerializedName("jobs")
  private List<String> jobs = new ArrayList<String>();
  
  @SerializedName("type")
  private String type = null;
  
  @SerializedName("files")
  private List<String> files = new ArrayList<String>();
  
  @SerializedName("importedBy")
  private String importedBy = null;
  
  @SerializedName("identify")
  private String identify = null;
  

  
  /**
   * Contains the changelist number if editing an existing changelist, or `new` if creating a new changelist.
   **/
  @ApiModelProperty(value = "Contains the changelist number if editing an existing changelist, or `new` if creating a new changelist.")
  public String getChange() {
    return change;
  }
  public void setChange(String change) {
    this.change = change;
  }

  
  /**
   * Name of current client workspace
   **/
  @ApiModelProperty(value = "Name of current client workspace")
  public String getClient() {
    return client;
  }
  public void setClient(String client) {
    this.client = client;
  }

  
  /**
   * Date the changelist was last modified.
   **/
  @ApiModelProperty(value = "Date the changelist was last modified.")
  public Date getDate() {
    return date;
  }
  public void setDate(Date date) {
    this.date = date;
  }

  
  /**
   * Name of the change owner.\n\nThe owner of an empty pending changelist (that is, a pending changelist without any files in it) can transfer ownership of the changelist to another existing user either by editing this field, or by using the -U user option.\n\nThe specified owner does not have to be a Perforce user.\nYou might want to use an arbitrary name if the user does not yet exist, or if you have deleted the user and need a placeholder until you can assign the spec to a new user.
   **/
  @ApiModelProperty(value = "Name of the change owner.\n\nThe owner of an empty pending changelist (that is, a pending changelist without any files in it) can transfer ownership of the changelist to another existing user either by editing this field, or by using the -U user option.\n\nThe specified owner does not have to be a Perforce user.\nYou might want to use an arbitrary name if the user does not yet exist, or if you have deleted the user and need a placeholder until you can assign the spec to a new user.")
  public String getUser() {
    return user;
  }
  public void setUser(String user) {
    this.user = user;
  }

  
  /**
   * `pending`, `shelved`, `submitted`, or `new`.\nNot editable by the user.\n\nThe status is `new` when the changelist is created, `pending` when it has been created but has not yet been submitted to the depot, `shelved` when its contents are shelved, and `submitted` when its contents have been stored in the depot.
   **/
  @ApiModelProperty(value = "`pending`, `shelved`, `submitted`, or `new`.\nNot editable by the user.\n\nThe status is `new` when the changelist is created, `pending` when it has been created but has not yet been submitted to the depot, `shelved` when its contents are shelved, and `submitted` when its contents have been stored in the depot.")
  public String getStatus() {
    return status;
  }
  public void setStatus(String status) {
    this.status = status;
  }

  
  /**
   * Textual description of changelist.\n\nIf you do not have access to a restricted changelist, the description is replaced with a \"no permission\" message.
   **/
  @ApiModelProperty(value = "Textual description of changelist.\n\nIf you do not have access to a restricted changelist, the description is replaced with a \"no permission\" message.")
  public String getDescription() {
    return description;
  }
  public void setDescription(String description) {
    this.description = description;
  }

  
  /**
   * A list of jobs that are fixed by this changelist.
   **/
  @ApiModelProperty(value = "A list of jobs that are fixed by this changelist.")
  public List<String> getJobs() {
    return jobs;
  }
  public void setJobs(List<String> jobs) {
    this.jobs = jobs;
  }

  
  /**
   * Type of change: `restricted` or `public`.\n\nThe Type: field can be used to hide the change or its description from users.\nA shelved or committed change (as denoted in the Status: field) that is restricted is accessible only to users who own the change or have list permission to at least one file in the change.\n\nPublic changes are displayed without restrictions.\n\nBy default, changelists are public.\nA Perforce superuser can set the default changelist type (for changelists created after the configurable is set) by setting the defaultChangeType configurable.
   **/
  @ApiModelProperty(value = "Type of change: `restricted` or `public`.\n\nThe Type: field can be used to hide the change or its description from users.\nA shelved or committed change (as denoted in the Status: field) that is restricted is accessible only to users who own the change or have list permission to at least one file in the change.\n\nPublic changes are displayed without restrictions.\n\nBy default, changelists are public.\nA Perforce superuser can set the default changelist type (for changelists created after the configurable is set) by setting the defaultChangeType configurable.")
  public String getType() {
    return type;
  }
  public void setType(String type) {
    this.type = type;
  }

  
  /**
   * The list of files submitted in this changelist.
   **/
  @ApiModelProperty(value = "The list of files submitted in this changelist.")
  public List<String> getFiles() {
    return files;
  }
  public void setFiles(List<String> files) {
    this.files = files;
  }

  
  /**
   * Displays the name of the user who ran the p4 fetch, p4 push, or p4 unzip command that imported this change into the server.\n\nThis field is primarily useful for distributed versioning (DVCS) scenarios, in which changelists are copied from one server to another, and help you correlate the changelist’s basic identity as it is copied.\n\nIn such configurations, Perforce recommends using the submit.identity configurable to enable automatic generation of changelist identities by the p4 submit.
   **/
  @ApiModelProperty(value = "Displays the name of the user who ran the p4 fetch, p4 push, or p4 unzip command that imported this change into the server.\n\nThis field is primarily useful for distributed versioning (DVCS) scenarios, in which changelists are copied from one server to another, and help you correlate the changelist’s basic identity as it is copied.\n\nIn such configurations, Perforce recommends using the submit.identity configurable to enable automatic generation of changelist identities by the p4 submit.")
  public String getImportedBy() {
    return importedBy;
  }
  public void setImportedBy(String importedBy) {
    this.importedBy = importedBy;
  }

  
  /**
   * Contains a label which uniquely identifies this changelist across all servers where it has been fetched, pushed, or unzipped.\n\nThis field is primarily useful for distributed versioning (DVCS) scenarios, in which changelists are copied from one server to another, and help you correlate the changelist’s basic identity as it is copied.\n\nIn such configurations, Perforce recommends using the submit.identity configurable to enable automatic generation of changelist identities by the p4 submit.
   **/
  @ApiModelProperty(value = "Contains a label which uniquely identifies this changelist across all servers where it has been fetched, pushed, or unzipped.\n\nThis field is primarily useful for distributed versioning (DVCS) scenarios, in which changelists are copied from one server to another, and help you correlate the changelist’s basic identity as it is copied.\n\nIn such configurations, Perforce recommends using the submit.identity configurable to enable automatic generation of changelist identities by the p4 submit.")
  public String getIdentify() {
    return identify;
  }
  public void setIdentify(String identify) {
    this.identify = identify;
  }

  

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    ChangeCommand changeCommand = (ChangeCommand) o;
    return Objects.equals(this.change, changeCommand.change) &&
        Objects.equals(this.client, changeCommand.client) &&
        Objects.equals(this.date, changeCommand.date) &&
        Objects.equals(this.user, changeCommand.user) &&
        Objects.equals(this.status, changeCommand.status) &&
        Objects.equals(this.description, changeCommand.description) &&
        Objects.equals(this.jobs, changeCommand.jobs) &&
        Objects.equals(this.type, changeCommand.type) &&
        Objects.equals(this.files, changeCommand.files) &&
        Objects.equals(this.importedBy, changeCommand.importedBy) &&
        Objects.equals(this.identify, changeCommand.identify);
  }

  @Override
  public int hashCode() {
    return Objects.hash(change, client, date, user, status, description, jobs, type, files, importedBy, identify);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class ChangeCommand {\n");
    
    sb.append("    change: ").append(toIndentedString(change)).append("\n");
    sb.append("    client: ").append(toIndentedString(client)).append("\n");
    sb.append("    date: ").append(toIndentedString(date)).append("\n");
    sb.append("    user: ").append(toIndentedString(user)).append("\n");
    sb.append("    status: ").append(toIndentedString(status)).append("\n");
    sb.append("    description: ").append(toIndentedString(description)).append("\n");
    sb.append("    jobs: ").append(toIndentedString(jobs)).append("\n");
    sb.append("    type: ").append(toIndentedString(type)).append("\n");
    sb.append("    files: ").append(toIndentedString(files)).append("\n");
    sb.append("    importedBy: ").append(toIndentedString(importedBy)).append("\n");
    sb.append("    identify: ").append(toIndentedString(identify)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
